@@ -12,6 +12,7 @@ import re
 if python_version_tuple()[0] < "3":
     from itertools import izip_longest
     from functools import partial
+
     _none_type = type(None)
     _int_type = int
     _long_type = long
@@ -25,6 +26,7 @@ if python_version_tuple()[0] < "3":
 else:
     from itertools import zip_longest as izip_longest
     from functools import reduce, partial
+
     _none_type = type(None)
     _int_type = int
     _long_type = int
@@ -37,6 +39,7 @@ else:
     def _is_file(f):
         return isinstance(f, io.IOBase)
 
+
 __author__ = "Sergey Astanin"
 __all__ = ["tabulate", "tabulate_formats", "simple_separated_format"]
 __version__ = "0.7.5"
@@ -80,13 +83,22 @@ DataRow = namedtuple("DataRow", ["begin", "sep", "end"])
 # with_header_hide:
 #
 #   - either None, to display all table elements unconditionally,
-#   - or a list of elements not to be displayed if the table has column 
+#   - or a list of elements not to be displayed if the table has column
 #     headers.
 #
-TableFormat = namedtuple("TableFormat", ["lineabove", "linebelowheader",
-                                         "linebetweenrows", "linebelow",
-                                         "headerrow", "datarow",
-                                         "padding", "with_header_hide"])
+TableFormat = namedtuple(
+    "TableFormat",
+    [
+        "lineabove",
+        "linebelowheader",
+        "linebetweenrows",
+        "linebelow",
+        "headerrow",
+        "datarow",
+        "padding",
+        "with_header_hide",
+    ],
+)
 
 
 def _pipe_segment_with_colons(align, colwidth):
@@ -94,183 +106,234 @@ def _pipe_segment_with_colons(align, colwidth):
     indicate column's alignment (as in `pipe` output format)."""
     w = colwidth
     if align in ["right", "decimal"]:
-        return ('-' * (w - 1)) + ":"
+        return ("-" * (w - 1)) + ":"
     elif align == "center":
-        return ":" + ('-' * (w - 2)) + ":"
+        return ":" + ("-" * (w - 2)) + ":"
     elif align == "left":
-        return ":" + ('-' * (w - 1))
+        return ":" + ("-" * (w - 1))
     else:
-        return '-' * w
+        return "-" * w
 
 
 def _pipe_line_with_colons(colwidths, colaligns):
     """Return a horizontal line with optional colons to indicate column's
     alignment (as in `pipe` output format)."""
-    segments = [_pipe_segment_with_colons(a, w)
-                for a, w in zip(colaligns, colwidths)]
+    segments = [_pipe_segment_with_colons(a, w) for a, w in zip(colaligns, colwidths)]
     return "|" + "|".join(segments) + "|"
 
 
 def _mediawiki_row_with_attrs(separator, cell_values, colwidths, colaligns):
-    alignment = { "left": '',
-                  "right": 'align="right"| ',
-                  "center": 'align="center"| ',
-                  "decimal": 'align="right"| ' }
+    alignment = {
+        "left": "",
+        "right": 'align="right"| ',
+        "center": 'align="center"| ',
+        "decimal": 'align="right"| ',
+    }
     # hard-coded padding _around_ align attribute and value together
     # rather than padding parameter which affects only the value
-    values_with_attrs = [' ' + alignment.get(a, '') + c + ' '
-                         for c, a in zip(cell_values, colaligns)]
+    values_with_attrs = [
+        " " + alignment.get(a, "") + c + " " for c, a in zip(cell_values, colaligns)
+    ]
     colsep = separator * 2
     return (separator + colsep.join(values_with_attrs)).rstrip()
 
 
 def _html_row_with_attrs(celltag, cell_values, colwidths, colaligns):
-    alignment = { "left": '',
-                  "right": ' style="text-align: right;"',
-                  "center": ' style="text-align: center;"',
-                  "decimal": ' style="text-align: right;"' }
-    values_with_attrs = ["<{0}{1}>{2}</{0}>".format(celltag, alignment.get(a, 
-      ''), c) for c, a in zip(cell_values, colaligns)]
+    alignment = {
+        "left": "",
+        "right": ' style="text-align: right;"',
+        "center": ' style="text-align: center;"',
+        "decimal": ' style="text-align: right;"',
+    }
+    values_with_attrs = [
+        "<{0}{1}>{2}</{0}>".format(celltag, alignment.get(a, ""), c)
+        for c, a in zip(cell_values, colaligns)
+    ]
     return "<tr>" + "".join(values_with_attrs).rstrip() + "</tr>"
 
 
 def _latex_line_begin_tabular(colwidths, colaligns, booktabs=False):
-    alignment = { "left": "l", "right": "r", "center": "c", "decimal": "r" }
+    alignment = {"left": "l", "right": "r", "center": "c", "decimal": "r"}
     tabular_columns_fmt = "".join([alignment.get(a, "l") for a in colaligns])
-    return "\n".join(["\\begin{tabular}{" + tabular_columns_fmt + "}",
-                      "\\toprule" if booktabs else "\hline"])
+    return "\n".join(
+        [
+            "\\begin{tabular}{" + tabular_columns_fmt + "}",
+            "\\toprule" if booktabs else "\hline",
+        ]
+    )
 
-LATEX_ESCAPE_RULES = {r"&": r"\&", r"%": r"\%", r"$": r"\$", r"#": r"\#",
-                      r"_": r"\_", r"^": r"\^{}", r"{": r"\{", r"}": r"\}",
-                      r"~": r"\textasciitilde{}", "\\": r"\textbackslash{}",
-                      r"<": r"\ensuremath{<}", r">": r"\ensuremath{>}"}
+
+LATEX_ESCAPE_RULES = {
+    r"&": r"\&",
+    r"%": r"\%",
+    r"$": r"\$",
+    r"#": r"\#",
+    r"_": r"\_",
+    r"^": r"\^{}",
+    r"{": r"\{",
+    r"}": r"\}",
+    r"~": r"\textasciitilde{}",
+    "\\": r"\textbackslash{}",
+    r"<": r"\ensuremath{<}",
+    r">": r"\ensuremath{>}",
+}
 
 
 def _latex_row(cell_values, colwidths, colaligns):
     def escape_char(c):
         return LATEX_ESCAPE_RULES.get(c, c)
+
     escaped_values = ["".join(map(escape_char, cell)) for cell in cell_values]
     rowfmt = DataRow("", "&", "\\\\")
     return _build_simple_row(escaped_values, rowfmt)
 
 
-_table_formats = {"simple":
-                  TableFormat(lineabove=Line("", "-", "  ", ""),
-                              linebelowheader=Line("", "-", "  ", ""),
-                              linebetweenrows=None,
-                              linebelow=Line("", "-", "  ", ""),
-                              headerrow=DataRow("", "  ", ""),
-                              datarow=DataRow("", "  ", ""),
-                              padding=0,
-                              with_header_hide=["lineabove", "linebelow"]),
-                  "plain":
-                  TableFormat(lineabove=None, linebelowheader=None,
-                              linebetweenrows=None, linebelow=None,
-                              headerrow=DataRow("", "  ", ""),
-                              datarow=DataRow("", "  ", ""),
-                              padding=0, with_header_hide=None),
-                  "grid":
-                  TableFormat(lineabove=Line("+", "-", "+", "+"),
-                              linebelowheader=Line("+", "=", "+", "+"),
-                              linebetweenrows=Line("+", "-", "+", "+"),
-                              linebelow=Line("+", "-", "+", "+"),
-                              headerrow=DataRow("|", "|", "|"),
-                              datarow=DataRow("|", "|", "|"),
-                              padding=1, with_header_hide=None),
-                  "fancy_grid":
-                  TableFormat(lineabove=Line("╒", "═", "╤", "╕"),
-                              linebelowheader=Line("╞", "═", "╪", "╡"),
-                              linebetweenrows=Line("├", "─", "┼", "┤"),
-                              linebelow=Line("╘", "═", "╧", "╛"),
-                              headerrow=DataRow("│", "│", "│"),
-                              datarow=DataRow("│", "│", "│"),
-                              padding=1, with_header_hide=None),
-                  "pipe":
-                  TableFormat(lineabove=_pipe_line_with_colons,
-                              linebelowheader=_pipe_line_with_colons,
-                              linebetweenrows=None,
-                              linebelow=None,
-                              headerrow=DataRow("|", "|", "|"),
-                              datarow=DataRow("|", "|", "|"),
-                              padding=1,
-                              with_header_hide=["lineabove"]),
-                  "orgtbl":
-                  TableFormat(lineabove=None,
-                              linebelowheader=Line("|", "-", "+", "|"),
-                              linebetweenrows=None,
-                              linebelow=None,
-                              headerrow=DataRow("|", "|", "|"),
-                              datarow=DataRow("|", "|", "|"),
-                              padding=1, with_header_hide=None),
-                  "psql":
-                  TableFormat(lineabove=Line("+", "-", "+", "+"),
-                              linebelowheader=Line("|", "-", "+", "|"),
-                              linebetweenrows=None,
-                              linebelow=Line("+", "-", "+", "+"),
-                              headerrow=DataRow("|", "|", "|"),
-                              datarow=DataRow("|", "|", "|"),
-                              padding=1, with_header_hide=None),
-                  "rst":
-                  TableFormat(lineabove=Line("", "=", "  ", ""),
-                              linebelowheader=Line("", "=", "  ", ""),
-                              linebetweenrows=None,
-                              linebelow=Line("", "=", "  ", ""),
-                              headerrow=DataRow("", "  ", ""),
-                              datarow=DataRow("", "  ", ""),
-                              padding=0, with_header_hide=None),
-                  "mediawiki":
-                  TableFormat(lineabove=Line("{| class=\"wikitable\" style=" + 
-                              "\"text-align: left;\"", "", "", "\n|+ <!-- " + 
-                              "caption --> \n|-"),
-                              linebelowheader=Line("|-", "", "", ""),
-                              linebetweenrows=Line("|-", "", "", ""),
-                              linebelow=Line("|}", "", "", ""),
-                              headerrow=partial(
-                                  _mediawiki_row_with_attrs, "!"),
-                              datarow=partial(_mediawiki_row_with_attrs, "|"),
-                              padding=0, with_header_hide=None),
-                  "html":
-                  TableFormat(lineabove=Line("<table>", "", "", ""),
-                              linebelowheader=None,
-                              linebetweenrows=None,
-                              linebelow=Line("</table>", "", "", ""),
-                              headerrow=partial(_html_row_with_attrs, "th"),
-                              datarow=partial(_html_row_with_attrs, "td"),
-                              padding=0, with_header_hide=None),
-                  "latex":
-                  TableFormat(lineabove=_latex_line_begin_tabular,
-                              linebelowheader=Line("\\hline", "", "", ""),
-                              linebetweenrows=None,
-                              linebelow=Line(
-                                  "\\hline\n\\end{tabular}", "", "", ""),
-                              headerrow=_latex_row,
-                              datarow=_latex_row,
-                              padding=1, with_header_hide=None),
-                  "latex_booktabs":
-                  TableFormat(lineabove=partial(_latex_line_begin_tabular, 
-                              booktabs=True),
-                              linebelowheader=Line("\\midrule", "", "", ""),
-                              linebetweenrows=None,
-                              linebelow=Line(
-                                  "\\bottomrule\n\\end{tabular}", "", "", ""),
-                              headerrow=_latex_row,
-                              datarow=_latex_row,
-                              padding=1, with_header_hide=None),
-                  "tsv":
-                  TableFormat(lineabove=None, linebelowheader=None,
-                              linebetweenrows=None, linebelow=None,
-                              headerrow=DataRow("", "\t", ""),
-                              datarow=DataRow("", "\t", ""),
-                              padding=0, with_header_hide=None)}
+_table_formats = {
+    "simple": TableFormat(
+        lineabove=Line("", "-", "  ", ""),
+        linebelowheader=Line("", "-", "  ", ""),
+        linebetweenrows=None,
+        linebelow=Line("", "-", "  ", ""),
+        headerrow=DataRow("", "  ", ""),
+        datarow=DataRow("", "  ", ""),
+        padding=0,
+        with_header_hide=["lineabove", "linebelow"],
+    ),
+    "plain": TableFormat(
+        lineabove=None,
+        linebelowheader=None,
+        linebetweenrows=None,
+        linebelow=None,
+        headerrow=DataRow("", "  ", ""),
+        datarow=DataRow("", "  ", ""),
+        padding=0,
+        with_header_hide=None,
+    ),
+    "grid": TableFormat(
+        lineabove=Line("+", "-", "+", "+"),
+        linebelowheader=Line("+", "=", "+", "+"),
+        linebetweenrows=Line("+", "-", "+", "+"),
+        linebelow=Line("+", "-", "+", "+"),
+        headerrow=DataRow("|", "|", "|"),
+        datarow=DataRow("|", "|", "|"),
+        padding=1,
+        with_header_hide=None,
+    ),
+    "fancy_grid": TableFormat(
+        lineabove=Line("╒", "═", "╤", "╕"),
+        linebelowheader=Line("╞", "═", "╪", "╡"),
+        linebetweenrows=Line("├", "─", "┼", "┤"),
+        linebelow=Line("╘", "═", "╧", "╛"),
+        headerrow=DataRow("│", "│", "│"),
+        datarow=DataRow("│", "│", "│"),
+        padding=1,
+        with_header_hide=None,
+    ),
+    "pipe": TableFormat(
+        lineabove=_pipe_line_with_colons,
+        linebelowheader=_pipe_line_with_colons,
+        linebetweenrows=None,
+        linebelow=None,
+        headerrow=DataRow("|", "|", "|"),
+        datarow=DataRow("|", "|", "|"),
+        padding=1,
+        with_header_hide=["lineabove"],
+    ),
+    "orgtbl": TableFormat(
+        lineabove=None,
+        linebelowheader=Line("|", "-", "+", "|"),
+        linebetweenrows=None,
+        linebelow=None,
+        headerrow=DataRow("|", "|", "|"),
+        datarow=DataRow("|", "|", "|"),
+        padding=1,
+        with_header_hide=None,
+    ),
+    "psql": TableFormat(
+        lineabove=Line("+", "-", "+", "+"),
+        linebelowheader=Line("|", "-", "+", "|"),
+        linebetweenrows=None,
+        linebelow=Line("+", "-", "+", "+"),
+        headerrow=DataRow("|", "|", "|"),
+        datarow=DataRow("|", "|", "|"),
+        padding=1,
+        with_header_hide=None,
+    ),
+    "rst": TableFormat(
+        lineabove=Line("", "=", "  ", ""),
+        linebelowheader=Line("", "=", "  ", ""),
+        linebetweenrows=None,
+        linebelow=Line("", "=", "  ", ""),
+        headerrow=DataRow("", "  ", ""),
+        datarow=DataRow("", "  ", ""),
+        padding=0,
+        with_header_hide=None,
+    ),
+    "mediawiki": TableFormat(
+        lineabove=Line(
+            '{| class="wikitable" style=' + '"text-align: left;"',
+            "",
+            "",
+            "\n|+ <!-- " + "caption --> \n|-",
+        ),
+        linebelowheader=Line("|-", "", "", ""),
+        linebetweenrows=Line("|-", "", "", ""),
+        linebelow=Line("|}", "", "", ""),
+        headerrow=partial(_mediawiki_row_with_attrs, "!"),
+        datarow=partial(_mediawiki_row_with_attrs, "|"),
+        padding=0,
+        with_header_hide=None,
+    ),
+    "html": TableFormat(
+        lineabove=Line("<table>", "", "", ""),
+        linebelowheader=None,
+        linebetweenrows=None,
+        linebelow=Line("</table>", "", "", ""),
+        headerrow=partial(_html_row_with_attrs, "th"),
+        datarow=partial(_html_row_with_attrs, "td"),
+        padding=0,
+        with_header_hide=None,
+    ),
+    "latex": TableFormat(
+        lineabove=_latex_line_begin_tabular,
+        linebelowheader=Line("\\hline", "", "", ""),
+        linebetweenrows=None,
+        linebelow=Line("\\hline\n\\end{tabular}", "", "", ""),
+        headerrow=_latex_row,
+        datarow=_latex_row,
+        padding=1,
+        with_header_hide=None,
+    ),
+    "latex_booktabs": TableFormat(
+        lineabove=partial(_latex_line_begin_tabular, booktabs=True),
+        linebelowheader=Line("\\midrule", "", "", ""),
+        linebetweenrows=None,
+        linebelow=Line("\\bottomrule\n\\end{tabular}", "", "", ""),
+        headerrow=_latex_row,
+        datarow=_latex_row,
+        padding=1,
+        with_header_hide=None,
+    ),
+    "tsv": TableFormat(
+        lineabove=None,
+        linebelowheader=None,
+        linebetweenrows=None,
+        linebelow=None,
+        headerrow=DataRow("", "\t", ""),
+        datarow=DataRow("", "\t", ""),
+        padding=0,
+        with_header_hide=None,
+    ),
+}
 
 
 tabulate_formats = list(sorted(_table_formats.keys()))
 
 
-_invisible_codes = re.compile(
-    r"\x1b\[\d*m|\x1b\[\d*\;\d*\;\d*m")  # ANSI color codes
+_invisible_codes = re.compile(r"\x1b\[\d*m|\x1b\[\d*\;\d*\;\d*m")  # ANSI color codes
 _invisible_codes_bytes = re.compile(
-    b"\x1b\[\d*m|\x1b\[\d*\;\d*\;\d*m")  # ANSI color codes
+    b"\x1b\[\d*m|\x1b\[\d*\;\d*\;\d*m"
+)  # ANSI color codes
 
 
 def simple_separated_format(separator):
@@ -282,10 +345,16 @@ def simple_separated_format(separator):
     True
 
     """
-    return TableFormat(None, None, None, None,
-                       headerrow=DataRow('', separator, ''),
-                       datarow=DataRow('', separator, ''),
-                       padding=0, with_header_hide=None)
+    return TableFormat(
+        None,
+        None,
+        None,
+        None,
+        headerrow=DataRow("", separator, ""),
+        datarow=DataRow("", separator, ""),
+        padding=0,
+        with_header_hide=None,
+    )
 
 
 def _isconvertible(conv, string):
@@ -315,10 +384,11 @@ def _isint(string, inttype=int):
     >>> _isint("123.45")
     False
     """
-    return type(string) is inttype or\
-        (isinstance(string, _binary_type) or isinstance(string, _text_type))\
-        and\
-        _isconvertible(inttype, string)
+    return (
+        type(string) is inttype
+        or (isinstance(string, _binary_type) or isinstance(string, _text_type))
+        and _isconvertible(inttype, string)
+    )
 
 
 def _type(string, has_invisible=True):
@@ -337,8 +407,9 @@ def _type(string, has_invisible=True):
 
     """
 
-    if has_invisible and \
-       (isinstance(string, _text_type) or isinstance(string, _binary_type)):
+    if has_invisible and (
+        isinstance(string, _text_type) or isinstance(string, _binary_type)
+    ):
         string = _strip_invisible(string)
 
     if string is None:
@@ -391,8 +462,7 @@ def _padleft(width, s, has_invisible=True):
     True
 
     """
-    iwidth = width + \
-        len(s) - len(_strip_invisible(s)) if has_invisible else width
+    iwidth = width + len(s) - len(_strip_invisible(s)) if has_invisible else width
     fmt = "{0:>%ds}" % iwidth
     return fmt.format(s)
 
@@ -400,13 +470,12 @@ def _padleft(width, s, has_invisible=True):
 def _padright(width, s, has_invisible=True):
     """Flush left.
 
-    >>> _padright(6, '\u044f\u0439\u0446\u0430') == 
+    >>> _padright(6, '\u044f\u0439\u0446\u0430') ==
         '\u044f\u0439\u0446\u0430  '
     True
 
     """
-    iwidth = width + \
-        len(s) - len(_strip_invisible(s)) if has_invisible else width
+    iwidth = width + len(s) - len(_strip_invisible(s)) if has_invisible else width
     fmt = "{0:<%ds}" % iwidth
     return fmt.format(s)
 
@@ -418,8 +487,7 @@ def _padboth(width, s, has_invisible=True):
     True
 
     """
-    iwidth = width + \
-        len(s) - len(_strip_invisible(s)) if has_invisible else width
+    iwidth = width + len(s) - len(_strip_invisible(s)) if has_invisible else width
     fmt = "{0:^%ds}" % iwidth
     return fmt.format(s)
 
@@ -448,9 +516,9 @@ def _visible_width(s):
 def _align_column(strings, alignment, minwidth=0, has_invisible=True):
     """[string] -> [padded_string]
 
-    >>> list(map(str,_align_column(["12.345", "-1234.5", "1.23", "1234.5", 
+    >>> list(map(str,_align_column(["12.345", "-1234.5", "1.23", "1234.5",
         "1e+234", "1.0e234"], "decimal")))
-    ['   12.345  ', '-1234.5    ', '    1.23   ', ' 1234.5    ', '    1e+234 ', 
+    ['   12.345  ', '-1234.5    ', '    1.23   ', ' 1234.5    ', '    1e+234 ',
     '    1.0e234']
 
     >>> list(map(str,_align_column(['123.4', '56.7890'], None)))
@@ -469,8 +537,7 @@ def _align_column(strings, alignment, minwidth=0, has_invisible=True):
         else:
             decimals = [_afterpoint(s) for s in strings]
         maxdecimals = max(decimals)
-        strings = [s + (maxdecimals - decs) * " "
-                   for s, decs in zip(strings, decimals)]
+        strings = [s + (maxdecimals - decs) * " " for s, decs in zip(strings, decimals)]
         padfn = _padleft
     elif not alignment:
         return strings
@@ -489,9 +556,8 @@ def _align_column(strings, alignment, minwidth=0, has_invisible=True):
 
 
 def _more_generic(type1, type2):
-    types = { _none_type: 0, int: 1, float: 2, _binary_type: 3, _text_type: 4 }
-    invtypes = { 4: _text_type, 3: _binary_type,
-        2: float, 1: int, 0: _none_type }
+    types = {_none_type: 0, int: 1, float: 2, _binary_type: 3, _text_type: 4}
+    invtypes = {4: _text_type, 3: _binary_type, 2: float, 1: int, 0: _none_type}
     moregeneric = max(types.get(type1, 4), types.get(type2, 4))
     return invtypes[moregeneric]
 
@@ -516,7 +582,7 @@ def _column_type(strings, has_invisible=True):
     True
 
     """
-    types = [_type(s, has_invisible) for s in strings ]
+    types = [_type(s, has_invisible) for s in strings]
     return reduce(_more_generic, types, int)
 
 
@@ -548,7 +614,8 @@ def _format(val, valtype, floatfmt, missingval="", has_invisible=True):
             return _text_type(val)
     elif valtype is float:
         is_a_colored_number = has_invisible and isinstance(
-            val, (_text_type, _binary_type))
+            val, (_text_type, _binary_type)
+        )
         if is_a_colored_number:
             raw_val = _strip_invisible(val)
             formatted_val = format(float(raw_val), floatfmt)
@@ -612,8 +679,7 @@ def _normalize_tabular_data(tabular_data, headers):
             names = tabular_data.index
             rows = [[v] + list(row) for v, row in zip(names, vals)]
         else:
-            raise ValueError(
-                "tabular data doesn't appear to be a dict or a DataFrame")
+            raise ValueError("tabular data doesn't appear to be a dict or a DataFrame")
 
         if headers == "keys":
             headers = list(map(_text_type, keys))  # headers should be strings
@@ -621,16 +687,22 @@ def _normalize_tabular_data(tabular_data, headers):
     else:  # it's a usual an iterable of iterables, or a NumPy array
         rows = list(tabular_data)
 
-        if (headers == "keys" and
-            hasattr(tabular_data, "dtype") and getattr(tabular_data.dtype, 
-              "names")):
+        if (
+            headers == "keys"
+            and hasattr(tabular_data, "dtype")
+            and getattr(tabular_data.dtype, "names")
+        ):
             # numpy record array
             headers = tabular_data.dtype.names
-        elif (headers == "keys" and len(rows) > 0 and 
-              isinstance(rows[0], tuple) and hasattr(rows[0], "_fields")):
+        elif (
+            headers == "keys"
+            and len(rows) > 0
+            and isinstance(rows[0], tuple)
+            and hasattr(rows[0], "_fields")
+        ):
             # namedtuple
             headers = list(map(_text_type, rows[0]._fields))
-        elif (len(rows) > 0 and isinstance(rows[0], dict)):
+        elif len(rows) > 0 and isinstance(rows[0], dict):
             # dict or OrderedDict
             uniq_keys = set()  # implements hashed lookup
             keys = []  # storage for set
@@ -645,7 +717,7 @@ def _normalize_tabular_data(tabular_data, headers):
                     if k not in uniq_keys:
                         keys.append(k)
                         uniq_keys.add(k)
-            if headers == 'keys':
+            if headers == "keys":
                 headers = keys
             elif isinstance(headers, dict):
                 # a dict of headers for a list of dicts
@@ -659,7 +731,8 @@ def _normalize_tabular_data(tabular_data, headers):
                     headers = []
             elif headers:
                 raise ValueError(
-                    'headers for a list of dicts is not a dict or a keyword')
+                    "headers for a list of dicts is not a dict or a keyword"
+                )
             rows = [[row.get(k) for k in keys] for row in rows]
         elif headers == "keys" and len(rows) > 0:
             # keys are column indices
@@ -683,9 +756,15 @@ def _normalize_tabular_data(tabular_data, headers):
     return rows, headers
 
 
-def tabulate(tabular_data, headers=(), tablefmt="simple",
-             floatfmt="g", numalign="decimal", stralign="left",
-             missingval=""):
+def tabulate(
+    tabular_data,
+    headers=(),
+    tablefmt="simple",
+    floatfmt="g",
+    numalign="decimal",
+    stralign="left",
+    missingval="",
+):
     """Format a fixed width table for pretty printing.
 
     >>> print(tabulate([[1, 2.34], [-56, "8.999"], ["2", "10001"]]))
@@ -755,7 +834,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
 
     Various plain-text table formats (`tablefmt`) are supported:
     'plain', 'simple', 'grid', 'pipe', 'orgtbl', 'rst', 'mediawiki',
-     'latex', and 'latex_booktabs'. Variable `tabulate_formats` contains the 
+     'latex', and 'latex_booktabs'. Variable `tabulate_formats` contains the
      list of currently supported formats.
 
     "plain" format doesn't use any pseudographics to draw tables,
@@ -767,7 +846,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
     spam         41.9999
     eggs        451
 
-    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]], 
+    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]],
       tablefmt="plain"))
     spam   41.9999
     eggs  451
@@ -781,7 +860,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
     spam         41.9999
     eggs        451
 
-    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]], 
+    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]],
       tablefmt="simple"))
     ----  --------
     spam   41.9999
@@ -801,7 +880,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
     | eggs      |  451      |
     +-----------+-----------+
 
-    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]], 
+    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]],
       tablefmt="grid"))
     +------+----------+
     | spam |  41.9999 |
@@ -831,7 +910,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
     | spam      |   41.9999 |
     | eggs      |  451      |
 
-    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]], 
+    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]],
       tablefmt="pipe"))
     |:-----|---------:|
     | spam |  41.9999 |
@@ -850,7 +929,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
     | eggs      |  451      |
 
 
-    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]], 
+    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]],
       tablefmt="orgtbl"))
     | spam |  41.9999 |
     | eggs | 451      |
@@ -876,7 +955,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
     "mediawiki" produces a table markup used in Wikipedia and on other
     MediaWiki-based sites:
 
-    >>> print(tabulate([["strings", "numbers"], ["spam", 41.9999], ["eggs", 
+    >>> print(tabulate([["strings", "numbers"], ["spam", 41.9999], ["eggs",
       "451.0"]], headers="firstrow", tablefmt="mediawiki"))
     {| class="wikitable" style="text-align: left;"
     |+ <!-- caption -->
@@ -890,7 +969,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
 
     "html" produces HTML markup:
 
-    >>> print(tabulate([["strings", "numbers"], ["spam", 41.9999], 
+    >>> print(tabulate([["strings", "numbers"], ["spam", 41.9999],
       ["eggs", "451.0"]],
     ...                headers="firstrow", tablefmt="html"))
     <table>
@@ -901,7 +980,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
 
     "latex" produces a tabular environment of LaTeX document markup:
 
-    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]], 
+    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]],
       tablefmt="latex"))
     \\begin{tabular}{lr}
     \\hline
@@ -913,7 +992,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
     "latex_booktabs" produces a tabular environment of LaTeX document markup
     using the booktabs.sty package:
 
-    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]], 
+    >>> print(tabulate([["spam", 41.9999], ["eggs", "451.0"]],
       tablefmt="latex_booktabs"))
     \\begin{tabular}{lr}
     \\toprule
@@ -928,8 +1007,10 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
 
     # optimization: look for ANSI control codes once,
     # enable smart width functions only if a control code is found
-    plain_text = '\n'.join(['\t'.join(map(_text_type, headers))] +
-      ['\t'.join(map(_text_type, row)) for row in list_of_lists])
+    plain_text = "\n".join(
+        ["\t".join(map(_text_type, headers))]
+        + ["\t".join(map(_text_type, row)) for row in list_of_lists]
+    )
     has_invisible = re.search(_invisible_codes, plain_text)
     if has_invisible:
         width_fn = _visible_width
@@ -939,24 +1020,30 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
     # format rows and columns, convert numeric values to strings
     cols = list(zip(*list_of_lists))
     coltypes = list(map(_column_type, cols))
-    cols = [[_format(v, ct, floatfmt, missingval, has_invisible) for v in c]
-            for c, ct in zip(cols, coltypes)]
+    cols = [
+        [_format(v, ct, floatfmt, missingval, has_invisible) for v in c]
+        for c, ct in zip(cols, coltypes)
+    ]
 
     # align columns
     aligns = [numalign if ct in [int, float] else stralign for ct in coltypes]
-    minwidths = [width_fn(h) + MIN_PADDING for h in headers] if headers else \
-        [0] * len(cols)
-    cols = [_align_column(c, a, minw, has_invisible)
-            for c, a, minw in zip(cols, aligns, minwidths)]
+    minwidths = (
+        [width_fn(h) + MIN_PADDING for h in headers] if headers else [0] * len(cols)
+    )
+    cols = [
+        _align_column(c, a, minw, has_invisible)
+        for c, a, minw in zip(cols, aligns, minwidths)
+    ]
 
     if headers:
         # align headers and add headers
-        t_cols = cols or [['']] * len(headers)
+        t_cols = cols or [[""]] * len(headers)
         t_aligns = aligns or [stralign] * len(headers)
-        minwidths = [max(minw, width_fn(c[0]))
-                     for minw, c in zip(minwidths, t_cols)]
-        headers = [_align_header(h, a, minw)
-                   for h, a, minw in zip(headers, t_aligns, minwidths)]
+        minwidths = [max(minw, width_fn(c[0])) for minw, c in zip(minwidths, t_cols)]
+        headers = [
+            _align_header(h, a, minw)
+            for h, a, minw in zip(headers, t_aligns, minwidths)
+        ]
         rows = list(zip(*cols))
     else:
         minwidths = [width_fn(c[0]) for c in cols]
@@ -1020,26 +1107,20 @@ def _format_table(fmt, headers, rows, colwidths, colaligns):
         lines.append(_build_line(padded_widths, colaligns, fmt.lineabove))
 
     if padded_headers:
-        lines.append(
-            _build_row(padded_headers, padded_widths, colaligns, headerrow))
+        lines.append(_build_row(padded_headers, padded_widths, colaligns, headerrow))
         if fmt.linebelowheader and "linebelowheader" not in hidden:
-            lines.append(
-                _build_line(padded_widths, colaligns, fmt.linebelowheader))
+            lines.append(_build_line(padded_widths, colaligns, fmt.linebelowheader))
 
     if padded_rows and fmt.linebetweenrows and "linebetweenrows" not in hidden:
         # initial rows with a line below
         for row in padded_rows[:-1]:
-            lines.append(
-                _build_row(row, padded_widths, colaligns, fmt.datarow))
-            lines.append(
-                _build_line(padded_widths, colaligns, fmt.linebetweenrows))
+            lines.append(_build_row(row, padded_widths, colaligns, fmt.datarow))
+            lines.append(_build_line(padded_widths, colaligns, fmt.linebetweenrows))
         # the last row without a line below
-        lines.append(
-            _build_row(padded_rows[-1], padded_widths, colaligns, fmt.datarow))
+        lines.append(_build_row(padded_rows[-1], padded_widths, colaligns, fmt.datarow))
     else:
         for row in padded_rows:
-            lines.append(
-                _build_row(row, padded_widths, colaligns, fmt.datarow))
+            lines.append(_build_row(row, padded_widths, colaligns, fmt.datarow))
 
     if fmt.linebelow and "linebelow" not in hidden:
         lines.append(_build_line(padded_widths, colaligns, fmt.linebelow))
@@ -1073,11 +1154,14 @@ def _main():
     import getopt
     import sys
     import textwrap
+
     usage = textwrap.dedent(_main.__doc__)
     try:
-        opts, args = getopt.getopt(sys.argv[1:],
-                     "h1o:s:F:f:",
-                     ["help", "header", "output", "sep=", "float=", "format="])
+        opts, args = getopt.getopt(
+            sys.argv[1:],
+            "h1o:s:F:f:",
+            ["help", "header", "output", "sep=", "float=", "format="],
+        )
     except getopt.GetoptError as e:
         print(e)
         print(usage)
@@ -1111,12 +1195,24 @@ def _main():
             if f == "-":
                 f = sys.stdin
             if _is_file(f):
-                _pprint_file(f, headers=headers, tablefmt=tablefmt,
-                             sep=sep, floatfmt=floatfmt, file=out)
+                _pprint_file(
+                    f,
+                    headers=headers,
+                    tablefmt=tablefmt,
+                    sep=sep,
+                    floatfmt=floatfmt,
+                    file=out,
+                )
             else:
                 with open(f) as fobj:
-                    _pprint_file(fobj, headers=headers, tablefmt=tablefmt,
-                                 sep=sep, floatfmt=floatfmt, file=out)
+                    _pprint_file(
+                        fobj,
+                        headers=headers,
+                        tablefmt=tablefmt,
+                        sep=sep,
+                        floatfmt=floatfmt,
+                        file=out,
+                    )
 
 
 def _pprint_file(fobject, headers, tablefmt, sep, floatfmt, file):
